﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CashCalc.Dialogs
{
    /// <summary>
    /// Form for specifying the date and the corresponding amount.
    /// </summary>
    public partial class DateAmountForm : Form
    {
        /// <summary>
        /// Default constructor.
        /// </summary>
        public DateAmountForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Constructor with specified date and amount.
        /// </summary>
        /// <param name="date">Date.</param>
        /// <param name="amount">Amount.</param>
        /// <param name="amountDeviation">Standard deviation of the amount.</param>
        public DateAmountForm(DateTime date, decimal amount, double amountDeviation)
            : this()
        {
            this.dateTimePicker.Value = date.Date;
            this.dateTimePicker.Enabled = false;
            this.amountNumericUpDown.Value = amount;
            this.amountDeviationNumericUpDown.Value = (decimal)amountDeviation;
        }

        /// <summary>
        /// Minimal allowed date.
        /// </summary>
        public DateTime MinDate
        {
            get
            {
                return this.dateTimePicker.MinDate;
            }
            set
            {
                this.dateTimePicker.MinDate = value;
            }
        }

        /// <summary>
        /// Maximal allowed date.
        /// </summary>
        public DateTime MaxDate
        {
            get
            {
                return this.dateTimePicker.MaxDate;
            }
            set
            {
                this.dateTimePicker.MaxDate = value;
            }
        }

        /// <summary>
        /// Date.
        /// </summary>
        public DateTime Date
        {
            get
            {
                return this.dateTimePicker.Value.Date;
            }
        }

        /// <summary>
        /// Amount.
        /// </summary>
        public Base.AmountWithDeviation Amount
        {
            get
            {
                return new Base.AmountWithDeviation
                {
                    Amount = this.amountNumericUpDown.Value,
                    AmountDeviation = (double)this.amountDeviationNumericUpDown.Value
                };
            }
        }

        private void getMeanButton_Click(object sender, EventArgs e)
        {
            GetMeanForm getMeanForm = new GetMeanForm();
            if (getMeanForm.ShowDialog() == DialogResult.OK)
            {
                this.amountNumericUpDown.Value = (decimal)getMeanForm.Mean;
            }
        }

        private void getStdDevButton_Click(object sender, EventArgs e)
        {
            GetStdDevForm getStdDevForm = new GetStdDevForm();
            if (getStdDevForm.ShowDialog() == DialogResult.OK)
            {
                this.amountDeviationNumericUpDown.Value = (decimal)getStdDevForm.StdDev;
            }
        }
    }
}
