﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CashCalc.Dialogs
{
    /// <summary>
    /// Form for exporting charts to image files.
    /// </summary>
    public partial class ExportToImageForm : Form
    {
        /// <summary>
        /// Default constructor.
        /// </summary>
        public ExportToImageForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Constructor with specified chart.
        /// </summary>
        /// <param name="chart">Chart.</param>
        public ExportToImageForm(System.Windows.Forms.DataVisualization.Charting.Chart chart)
            : this()
        {
            this.chart = chart;
        }

        private System.Windows.Forms.DataVisualization.Charting.Chart chart;

        private void exportButton_Click(object sender, EventArgs e)
        {
            SaveFileDialog saveFileDialog = new SaveFileDialog();
            System.Windows.Forms.DataVisualization.Charting.ChartImageFormat chartImageFormat;
            if (this.jpegRadioButton.Checked)
            {
                saveFileDialog.Filter = "JPEG image format (*.jpeg)|*.jpeg|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.Jpeg;
            }
            else if (this.pngRadioButton.Checked)
            {
                saveFileDialog.Filter = "PNG image format (*.png)|*.png|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.Png;
            }
            else if (this.bmpRadioButton.Checked)
            {
                saveFileDialog.Filter = "Bitmap (BMP) image format (*.bmp)|*.bmp|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.Bmp;
            }
            else if (this.tiffRadioButton.Checked)
            {
                saveFileDialog.Filter = "TIFF image format (*.tiff)|*.tiff|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.Tiff;
            }
            else if (this.gifRadioButton.Checked)
            {
                saveFileDialog.Filter = "GIF image format (*.gif)|*.gif|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.Gif;
            }
            else if (this.emfRadioButton.Checked)
            {
                saveFileDialog.Filter = "Windows Enhanced Metafile (EMF) image format (*.emf)|*.emf|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.Emf;
            }
            else if (this.emfDualRadioButton.Checked)
            {
                saveFileDialog.Filter = "Windows Enhanced Metafile Dual (EMF-dual) image format (*.emf-dual)|*.emf-dual|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.EmfDual;
            }
            else if (this.emfPlusRadioButton.Checked)
            {
                saveFileDialog.Filter = "Windows Enhanced Metafile Plus (EMF+) image format (*.emf+)|*.emf+|All files (*.*)|*.*";
                chartImageFormat = System.Windows.Forms.DataVisualization.Charting.ChartImageFormat.EmfPlus;
            }
            else
            {
                throw new InvalidProgramException("Unknown image format");
            }
            saveFileDialog.RestoreDirectory = true;
            System.Windows.Forms.DialogResult dialogResult = saveFileDialog.ShowDialog();
            if (dialogResult == System.Windows.Forms.DialogResult.OK)
            {
                this.chart.SuspendLayout();
                DockStyle oldDockStyle = this.chart.Dock;
                Size oldSize = this.chart.Size;
                this.chart.Dock = DockStyle.None;
                this.chart.Size = new Size(
                    (int)this.widthNumericUpDown.Value,
                    (int)this.heightNumericUpDown.Value);
                this.chart.SaveImage(saveFileDialog.FileName, chartImageFormat);
                this.chart.Size = oldSize;
                this.chart.Dock = oldDockStyle;
                this.chart.ResumeLayout();
            }
        }
    }
}
