﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CashCalc.Dialogs
{
    /// <summary>
    /// Form for obtaining the mean of the entered comma separated values.
    /// </summary>
    public partial class GetMeanForm : Form
    {
        /// <summary>
        /// Default constructor.
        /// </summary>
        public GetMeanForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Mean.
        /// </summary>
        public double Mean
        {
            get
            {
                return this.Compute(false);
            }
        }

        private double Compute(bool showMessage)
        {
            try
            {
                List<double> values = ParseValues.ParseDoubleValues(this.inputTextBox.Text.Trim());
                if (values != null && values.Count > 0)
                {
                    double mean = values.Average();
                    if (showMessage)
                    {
                        this.outputTextBox.Text = mean.ToString("F", System.Globalization.CultureInfo.InvariantCulture);
                    }
                    return mean;
                }
                else
                {
                    if (showMessage)
                    {
                        this.outputTextBox.Text = "Error";
                        MessageBox.Show("The input is empty.", "Warning");
                    }
                    return 0.0;
                }
            }
            catch (Exception exception)
            {
                if (showMessage)
                {
                    this.outputTextBox.Text = "Error";
                    MessageBox.Show("The input could not be parsed due to the following error: " + exception.Message, "Warning");
                }
                return 0.0;
            }
        }

        private void computeButton_Click(object sender, EventArgs e)
        {
            this.Compute(true);
        }
    }
}
