﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CashCalc.Dialogs
{
    /// <summary>
    /// Form for obtaining the standard deviation of the entered comma separated values.
    /// </summary>
    public partial class GetStdDevForm : Form
    {
        /// <summary>
        /// Default constructor.
        /// </summary>
        public GetStdDevForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Standard deviation.
        /// </summary>
        public double StdDev
        {
            get
            {
                return this.Compute(false);
            }
        }

        private double Compute(bool showMessage)
        {
            try
            {
                List<double> values = ParseValues.ParseDoubleValues(this.inputTextBox.Text.Trim());
                if (values != null && values.Count > 1)
                {
                    double mean = values.Average();
                    double stdDev = values.Sum(x => (x - mean) * (x - mean)) / (values.Count - 1);
                    if (showMessage)
                    {
                        this.outputTextBox.Text = mean.ToString("F", System.Globalization.CultureInfo.InvariantCulture);
                    }
                    return stdDev;
                }
                else
                {
                    if (showMessage)
                    {
                        this.outputTextBox.Text = "Error";
                        if (values.Count == 0)
                        {
                            MessageBox.Show("The input is empty.", "Warning");
                        }
                        else if (values.Count == 1)
                        {
                            MessageBox.Show("The input must contain at least two values.", "Warning");
                        }
                    }
                    return 0.0;
                }
            }
            catch (Exception exception)
            {
                if (showMessage)
                {
                    this.outputTextBox.Text = "Error";
                    MessageBox.Show("The input could not be parsed due to the following error: " + exception.Message, "Warning");
                }
                return 0.0;
            }
        }

        private void computeButton_Click(object sender, EventArgs e)
        {
            this.Compute(true);
        }
    }
}
