﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace CashCalc.Dialogs
{
    /// <summary>
    /// Static class used to parse comma-separated values from the input text.
    /// </summary>
    public static class ParseValues
    {
        /// <summary>
        /// Separators delimiting the values in the input text.
        /// </summary>
        public static char[] separator = new char[] { ',', ';', ' ', '\t', '\r', '\n' };

        /// <summary>
        /// Returns the list of double values from the input text.
        /// </summary>
        /// <param name="text">Comma-separated double values.</param>
        /// <returns>List of double values.</returns>
        public static List<double> ParseDoubleValues(string text)
        {
            string[] parts = text.Split(separator, StringSplitOptions.RemoveEmptyEntries);
            List<double> result = new List<double>(parts.Length);
            foreach (string part in parts)
            {
                double partValue = Double.Parse(part, System.Globalization.NumberStyles.Float, System.Globalization.CultureInfo.InvariantCulture);
                result.Add(partValue);
            }
            return result;
        }
    }
}
