﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using CashCalc.Base;

namespace CashCalc.UserControls
{
    /// <summary>
    /// User control for specifying any kind of account.
    /// </summary>
    public partial class AccountUserControl : UserControl
    {
        /// <summary>
        /// Default constructor.
        /// </summary>
        public AccountUserControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Title of the account.
        /// </summary>
        public string Title
        {
            get { return this.titleTextBox.Text.Trim(); }
            set { this.titleTextBox.Text = value.Trim(); }
        }

        /// <summary>
        /// Account specified by this user control.
        /// </summary>
        public Account Account
        {
            get
            {
                Account account = null;
                if (this.tabControl.SelectedTab == this.constantAccountTabPage) account = this.constantAccountUserControl.Account;
                else if (this.tabControl.SelectedTab == this.continuousMonthAccountTabPage) account = this.continuousMonthAccountUserControl.Account;
                else if (this.tabControl.SelectedTab == this.everyNthDayAccountTabPage) account = this.everyNthDayAccountUserControl.Account;
                else if (this.tabControl.SelectedTab == this.everyNthMonthAccountTabPage) account = this.everyNthMonthAccountUserControl.Account;
                else if (this.tabControl.SelectedTab == this.weekAccountTabPage) account = this.weekAccountUserControl.Account;
                if (account != null) account.Title = this.Title;
                return account;
            }
            set
            {
                this.Title = value.Title;
                if (value != null)
                {
                    if (value is ConstantAccount)
                    {
                        this.tabControl.SelectedTab = this.constantAccountTabPage;
                        this.constantAccountUserControl.Account = value as ConstantAccount;
                    }
                    else if (value is ContinuousMonthAccount)
                    {
                        this.tabControl.SelectedTab = this.continuousMonthAccountTabPage;
                        this.continuousMonthAccountUserControl.Account = value as ContinuousMonthAccount;
                    }
                    else if (value is EveryNthDayAccount)
                    {
                        this.tabControl.SelectedTab = this.everyNthDayAccountTabPage;
                        this.everyNthDayAccountUserControl.Account = value as EveryNthDayAccount;
                    }
                    else if (value is EveryNthMonthAccount)
                    {
                        this.tabControl.SelectedTab = this.everyNthMonthAccountTabPage;
                        this.everyNthMonthAccountUserControl.Account = value as EveryNthMonthAccount;
                    }
                    else if (value is WeekAccount)
                    {
                        this.tabControl.SelectedTab = this.weekAccountTabPage;
                        this.weekAccountUserControl.Account = value as WeekAccount;
                    }
                }
            }
        }
    }
}
