﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using CashCalc.Base;
using CashCalc.Dialogs;

namespace CashCalc.UserControls
{
    /// <summary>
    /// User control for specifying the continuous month account.
    /// </summary>
    public partial class ContinuousMonthAccountUserControl : UserControl
    {
        /// <summary>
        /// Default constructor.
        /// </summary>
        public ContinuousMonthAccountUserControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Continuous month account.
        /// </summary>
        public ContinuousMonthAccount Account
        {
            get
            {
                return new ContinuousMonthAccount(
                    this.StartDate,
                    this.EndDate,
                    this.amount30NumericUpDown.Value,
                    (double)this.amount30DeviationNumericUpDown.Value);
            }
            set
            {
                this.StartDate = value.StartDate;
                this.EndDate = value.EndDate;
                this.amount30NumericUpDown.Value = value.Amount30.Amount;
                this.amount30DeviationNumericUpDown.Value = (decimal)value.Amount30.AmountDeviation;
            }
        }

        /// <summary>
        /// Starting date.
        /// </summary>
        public DateTime StartDate
        {
            get { return this.startDateTimePicker.Value.Date; }
            set { this.startDateTimePicker.Value = value.Date; }
        }

        /// <summary>
        /// Ending date.
        /// </summary>
        public DateTime EndDate
        {
            get
            {
                if (this.endDateCheckBox.Checked)
                {
                    return this.endDateTimePicker.Value.Date;
                }
                else
                {
                    return DateTime.MaxValue.Date;
                }
            }
            set
            {
                if (value.Date.Equals(DateTime.MaxValue.Date))
                {
                    this.endDateCheckBox.Checked = false;
                }
                else
                {
                    this.endDateCheckBox.Checked = true;
                    this.endDateTimePicker.Value = value.Date;
                }
            }
        }

        private void getMeanButton_Click(object sender, EventArgs e)
        {
            GetMeanForm getMeanForm = new GetMeanForm();
            if (getMeanForm.ShowDialog() == DialogResult.OK)
            {
                this.amount30NumericUpDown.Value = (decimal)getMeanForm.Mean;
            }
        }

        private void getStdDevButton_Click(object sender, EventArgs e)
        {
            GetStdDevForm getStdDevForm = new GetStdDevForm();
            if (getStdDevForm.ShowDialog() == DialogResult.OK)
            {
                this.amount30DeviationNumericUpDown.Value = (decimal)getStdDevForm.StdDev;
            }
        }

        private void startDateTimePicker_ValueChanged(object sender, EventArgs e)
        {
            this.endDateTimePicker.MinDate = this.startDateTimePicker.Value;
        }

        private void endDateCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if (this.endDateCheckBox.Checked)
            {
                this.endDateTimePicker.Enabled = true;
                this.endDateTimePicker.MinDate = this.startDateTimePicker.Value;
            }
            else
            {
                this.endDateTimePicker.Enabled = false;
            }
        }
    }
}
