﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using CashCalc.Base;

namespace CashCalc.UserControls
{
    /// <summary>
    /// User control for specifying account whose balance changes every week by a constant amount.
    /// </summary>
    public partial class WeekAccountUserControl : UserControl
    {
        /// <summary>
        /// Default constructor.
        /// </summary>
        public WeekAccountUserControl()
        {
            InitializeComponent();
            this.enumerableAccountUserControl.ValidDates = (() => this.Account.Dates);
        }

        /// <summary>
        /// Account whose balance changes every week by a constant amount.
        /// </summary>
        public WeekAccount Account
        {
            get
            {
                WeekAccount.DayFlags dayFlags = 0;
                if (this.mondayCheckBox.Checked) dayFlags |= WeekAccount.DayFlags.Monday;
                if (this.tuesdayCheckBox.Checked) dayFlags |= WeekAccount.DayFlags.Tuesday;
                if (this.wednesdayCheckBox.Checked) dayFlags |= WeekAccount.DayFlags.Wednesday;
                if (this.thursdayCheckBox.Checked) dayFlags |= WeekAccount.DayFlags.Thursday;
                if (this.fridayCheckBox.Checked) dayFlags |= WeekAccount.DayFlags.Friday;
                if (this.saturdayCheckBox.Checked) dayFlags |= WeekAccount.DayFlags.Saturday;
                if (this.sundayCheckBox.Checked) dayFlags |= WeekAccount.DayFlags.Sunday;
                return new WeekAccount(
                    this.enumerableAccountUserControl.StartDate,
                    this.enumerableAccountUserControl.EndDate,
                    this.enumerableAccountUserControl.Amount,
                    this.enumerableAccountUserControl.AmountDeviation,
                    dayFlags,
                    this.enumerableAccountUserControl.Exceptions);
            }
            set
            {
                this.enumerableAccountUserControl.Account = value;
                if ((value.SelectedDays & WeekAccount.DayFlags.Monday) == WeekAccount.DayFlags.Monday) this.mondayCheckBox.Checked = true; else this.mondayCheckBox.Checked = false;
                if ((value.SelectedDays & WeekAccount.DayFlags.Tuesday) == WeekAccount.DayFlags.Tuesday) this.tuesdayCheckBox.Checked = true; else this.tuesdayCheckBox.Checked = false;
                if ((value.SelectedDays & WeekAccount.DayFlags.Wednesday) == WeekAccount.DayFlags.Wednesday) this.wednesdayCheckBox.Checked = true; else this.wednesdayCheckBox.Checked = false;
                if ((value.SelectedDays & WeekAccount.DayFlags.Thursday) == WeekAccount.DayFlags.Thursday) this.thursdayCheckBox.Checked = true; else this.thursdayCheckBox.Checked = false;
                if ((value.SelectedDays & WeekAccount.DayFlags.Friday) == WeekAccount.DayFlags.Friday) this.fridayCheckBox.Checked = true; else this.fridayCheckBox.Checked = false;
                if ((value.SelectedDays & WeekAccount.DayFlags.Saturday) == WeekAccount.DayFlags.Saturday) this.saturdayCheckBox.Checked = true; else this.saturdayCheckBox.Checked = false;
                if ((value.SelectedDays & WeekAccount.DayFlags.Sunday) == WeekAccount.DayFlags.Sunday) this.sundayCheckBox.Checked = true; else this.sundayCheckBox.Checked = false;
            }
        }

        private void weekCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.enumerableAccountUserControl.UpdateExceptionListView();
        }
    }
}
