﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using System.Xml.Serialization;

using CashCalc.Base;

namespace CashCalc
{
    /// <summary>
    /// Xml representation of the CashCalc project.
    /// </summary>
    [XmlRoot("CashCalc")]
    public class XmlCashCalc
    {
        /// <summary>
        /// Default constructor of the XmlCashCalc class (due to serialization).
        /// </summary>
        public XmlCashCalc()
        {

        }

        /// <summary>
        /// Constructor of the XmlCashCalc class.
        /// </summary>
        /// <param name="inflowOutflowAccount">Inflow/Outflow account of the CashCalc project.</param>
        /// <param name="fromDate">First date of the account chart view.</param>
        /// <param name="toDate">Last date of the account chart view.</param>
        public XmlCashCalc(InflowOutflowAccount inflowOutflowAccount, DateTime fromDate, DateTime toDate)
        {
            this.InflowOutflowAccount = inflowOutflowAccount;
            this.FromDate = fromDate.Date;
            this.ToDate = toDate.Date;
        }

        /// <summary>
        /// Inflow/Outflow account of the CashCalc project.
        /// </summary>
        public InflowOutflowAccount InflowOutflowAccount { get; set; }

        /// <summary>
        /// First date of the account chart view.
        /// </summary>
        public DateTime FromDate { get; set; }

        /// <summary>
        /// Last date of the account chart view.
        /// </summary>
        public DateTime ToDate { get; set; }
    }
}
